@@ -329,7 +329,7 @@ bool BookTextView::onStylusClick(int x, int y, int count) {
 
 bool BookTextView::_onStylusRelease(int x, int y) {
 	FBReader &fbreader = FBReader::Instance();
-	if (!isReleasedWithoutMotion()) {
+	if (isPressProcessed()) {
 		return false;
 	}
 
